@@ -2,7 +2,7 @@
 
 {
     package WebService::Braintree::AdvancedSearchNodes;
-$WebService::Braintree::AdvancedSearchNodes::VERSION = '1.2';
+$WebService::Braintree::AdvancedSearchNodes::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -11,7 +11,7 @@ use 5.010_001;
 
 {
     package WebService::Braintree::SearchNode;
-$WebService::Braintree::SearchNode::VERSION = '1.2';
+$WebService::Braintree::SearchNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -42,7 +42,7 @@ use 5.010_001;
 
 {
     package WebService::Braintree::IsNode;
-$WebService::Braintree::IsNode::VERSION = '1.2';
+$WebService::Braintree::IsNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -59,7 +59,7 @@ use 5.010_001;
 
 {
     package WebService::Braintree::EqualityNode;
-$WebService::Braintree::EqualityNode::VERSION = '1.2';
+$WebService::Braintree::EqualityNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -76,7 +76,7 @@ use 5.010_001;
 
 {
     package WebService::Braintree::KeyValueNode;
-$WebService::Braintree::KeyValueNode::VERSION = '1.2';
+$WebService::Braintree::KeyValueNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -103,7 +103,7 @@ use 5.010_001;
 
 {
     package WebService::Braintree::PartialMatchNode;
-$WebService::Braintree::PartialMatchNode::VERSION = '1.2';
+$WebService::Braintree::PartialMatchNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -125,7 +125,7 @@ use 5.010_001;
 
 {
     package WebService::Braintree::TextNode;
-$WebService::Braintree::TextNode::VERSION = '1.2';
+$WebService::Braintree::TextNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -142,7 +142,7 @@ use 5.010_001;
 
 {
     package WebService::Braintree::RangeNode;
-$WebService::Braintree::RangeNode::VERSION = '1.2';
+$WebService::Braintree::RangeNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
@@ -172,17 +172,26 @@ use 5.010_001;
 
 {
     package WebService::Braintree::MultipleValuesNode;
-$WebService::Braintree::MultipleValuesNode::VERSION = '1.2';
+$WebService::Braintree::MultipleValuesNode::VERSION = '1.3';
 use 5.010_001;
     use strictures 1;
 
     use Carp;
     use Moose;
-    use WebService::Braintree::Util qw(difference_arrays is_arrayref);
+    use WebService::Braintree::Util qw(is_arrayref);
     extends 'WebService::Braintree::SearchNode';
 
     has allowed_values => (is => 'ro');
 
+    sub difference_arrays {
+        my ($array1, $array2) = @_;
+        my @diff;
+        foreach my $element (@$array1) {
+            push(@diff, $element) unless grep { $element eq $_ } @$array2;
+        }
+        return \@diff;
+    }
+
     sub default_criteria {
         return [];
     }
