@@ -9,6 +9,10 @@ use strictures 1;
 use Moose;
 extends 'WebService::Braintree::PaymentMethodGatewayBase';
 
+use Carp qw(confess);
+
+use WebService::Braintree::Util qw(is_not_empty validate_id);
+
 use WebService::Braintree::_::EuropeBankAccount;
 
 sub find {
