@@ -1,7 +1,7 @@
 # vim: sw=4 ts=4 ft=perl
 
 package WebService::Braintree::PaymentMethod;
-$WebService::Braintree::PaymentMethod::VERSION = '1.2';
+$WebService::Braintree::PaymentMethod::VERSION = '1.3';
 use 5.010_001;
 use strictures 1;
 
@@ -46,13 +46,22 @@ sub update {
 
 =head2 delete()
 
-This takes a token and deletes the corresponding payment method (if found).
+This takes a token and an optional hashref of parameters. It will delete the
+corresponding payment method (if found).
+
+The optional hashref can contain the following key(s):
+
+=over 4
+
+=item * revoke_all_grants
+
+=back
 
 =cut
 
 sub delete {
-    my ($class, $token) = @_;
-    $class->gateway->payment_method->delete($token);
+    my ($class, $token, $params) = @_;
+    $class->gateway->payment_method->delete($token, $params);
 }
 
 =head2 grant()
