@@ -11,14 +11,11 @@ with 'WebService::Braintree::Role::MakeRequest';
 
 use Carp qw(confess);
 use DateTime;
+
 use WebService::Braintree::Util qw(hash_to_query_string);
 use WebService::Braintree::Digest qw(hexdigest);
-use WebService::Braintree::HTTP;
-use WebService::Braintree::Result;
 use WebService::Braintree::TransparentRedirect::QueryString;
 
-has 'gateway' => (is => 'ro');
-
 sub confirm {
     my ($self, $query_string) = @_;
     my $qs = WebService::Braintree::TransparentRedirect::QueryString->new(config => $self->gateway->config);
